==> apache-ofbiz-18.12.19.zip: apache-ofbiz-18.12.19/framework/widget/src/main/java/org/apache/ofbiz/widget/model/ModelActionUtil.java <==
/*******************************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *******************************************************************************/
package org.apache.ofbiz.widget.model;

import java.util.Map;

import org.apache.ofbiz.base.util.UtilValidate;
import org.apache.ofbiz.base.util.collections.FlexibleMapAccessor;

public class ModelActionUtil {

    /**
     * @param context
     * @param result
     * @param resultMapNameAcsr
     */
    protected static void contextPutQueryStringOrAllResult(Map<String, Object> context, Map<String, Object> result, FlexibleMapAccessor<Map<String, Object>> resultMapNameAcsr) {
        if (!resultMapNameAcsr.isEmpty()) {
            resultMapNameAcsr.put(context, result);
            String queryString = (String) result.get("queryString");
            context.put("queryString", queryString);
            context.put("queryStringMap", result.get("queryStringMap"));
            if (UtilValidate.isNotEmpty(queryString)) {
                String queryStringEncoded = queryString.replaceAll("&", "%26");
                context.put("queryStringEncoded", queryStringEncoded);
            }
        } else {
            context.putAll(result);
        }
    }
}

==> apache-ofbiz-24.09.04.zip: apache-ofbiz-24.09.04/framework/widget/src/main/java/org/apache/ofbiz/widget/model/ModelActionUtil.java <==
/*******************************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *******************************************************************************/
package org.apache.ofbiz.widget.model;

import java.util.Map;

import org.apache.ofbiz.base.util.UtilValidate;
import org.apache.ofbiz.base.util.collections.FlexibleMapAccessor;

public class ModelActionUtil {

    /**
     * @param context
     * @param result
     * @param resultMapNameAcsr
     */
    protected static void contextPutQueryStringOrAllResult(Map<String, Object> context, Map<String, Object> result,
                                                           FlexibleMapAccessor<Map<String, Object>> resultMapNameAcsr) {
        if (!resultMapNameAcsr.isEmpty()) {
            resultMapNameAcsr.put(context, result);
            String queryString = (String) result.get("queryString");
            context.put("queryString", queryString);
            context.put("queryStringMap", result.get("queryStringMap"));
            if (UtilValidate.isNotEmpty(queryString)) {
                String queryStringEncoded = queryString.replace("&", "%26");
                context.put("queryStringEncoded", queryStringEncoded);
            }
        } else {
            context.putAll(result);
        }
    }
}
